# lettuceSee
The lettuceSee package contains functions for the segmentation and analysis of plant images. For further information 
go to the [Read the Docs page](https://lettucesee.readthedocs.io/en/latest/index.html#).